@@ -456,19 +456,6 @@ book_backend_kolab_remove (EBookBackendSync *backend,
 
 	g_warning ("%s: FIXME implement me", __func__);
 
-#if 0 /* FIXME old */
-	g_debug ("%s()[%u] called.", __func__, __LINE__);
-	if (e_book_backend_is_loaded (E_BOOK_BACKEND (backend)) != FALSE) {
-		g_object_unref (priv->book_koma);
-		priv->book_koma = NULL;
-	}
-
-	e_book_backend_set_is_writable (E_BOOK_BACKEND (backend), FALSE);
-	e_book_backend_notify_writable (E_BOOK_BACKEND (backend), FALSE);
-	e_book_backend_notify_connection_status (E_BOOK_BACKEND (backend), FALSE);
-	e_book_backend_set_is_loaded (E_BOOK_BACKEND (backend), FALSE);
-#endif /* FIXME*/
-
 	book_backend_kolab_notify_removed (self);
 }
 
@@ -492,60 +479,6 @@ book_backend_kolab_refresh (EBookBackendSync *backend,
 	g_warning ("%s: FIXME implement me", __func__);
 }
 
-#if 0 /* probably not needed */
-static gboolean
-book_backend_kolab_get_backend_property (EBookBackendSync *backend,
-                                         EDataBook *book,
-                                         GCancellable *cancellable,
-                                         const gchar *prop_name,
-                                         gchar **prop_value,
-                                         GError **error)
-{
-	EBookBackendKolab *self = NULL;
-	EBookBackendKolabPrivate *priv = NULL;
-
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-	e_return_data_book_error_val_if_fail (E_IS_BOOK_BACKEND_KOLAB (backend), E_DATA_BOOK_STATUS_INVALID_ARG);
-	e_return_data_book_error_val_if_fail (E_IS_DATA_BOOK (book), E_DATA_BOOK_STATUS_INVALID_ARG);
-	/* cancellable may be NULL */
-	e_return_data_book_error_val_if_fail (prop_name != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
-	e_return_data_book_error_val_if_fail (prop_value != NULL && *prop_value == NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
-
-	self = E_BOOK_BACKEND_KOLAB (backend);
-	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
-
-	g_error ("%s: FIXME implement me", __func__);
-
-	return TRUE;
-}
-#endif
-
-#if 0 /* probably not needed */
-static gboolean
-book_backend_kolab_set_backend_property (EBookBackendSync *backend,
-                                         EDataBook *book,
-                                         GCancellable *cancellable,
-                                         const gchar *prop_name,
-                                         const gchar *prop_value,
-                                         GError **error)
-{
-	EBookBackendKolab *self = NULL;
-	EBookBackendKolabPrivate *priv = NULL;
-
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-	e_return_data_book_error_val_if_fail (E_IS_BOOK_BACKEND_KOLAB (backend), E_DATA_BOOK_STATUS_INVALID_ARG);
-	e_return_data_book_error_val_if_fail (E_IS_DATA_BOOK (book), E_DATA_BOOK_STATUS_INVALID_ARG);
-	/* cancellable may be NULL */
-	e_return_data_book_error_val_if_fail (prop_name != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
-	e_return_data_book_error_val_if_fail (prop_value != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
-
-	self = E_BOOK_BACKEND_KOLAB (backend);
-	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
-
-	g_error ("%s: FIXME implement me", __func__);
-}
-#endif
-
 static void
 book_backend_kolab_create_contacts (EBookBackendSync *backend,
                                     EDataBook *book,
@@ -924,12 +857,6 @@ book_backend_kolab_get_backend_property (EBookBackendSync *backend,
 
 	if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
 		*prop_value = g_strdup ("net,bulk-removes,contact-lists,do-initial-query");
-#if 0
-		if (e_book_backend_mapi_is_marked_for_offline (ebma))
-			*prop_value = g_strdup ("net,bulk-removes,contact-lists,do-initial-query");
-		else
-			*prop_value = g_strdup ("net,bulk-removes,contact-lists");
-#endif
 	} else if (g_str_equal (prop_name, BOOK_BACKEND_PROPERTY_REQUIRED_FIELDS)) {
 		*prop_value = g_strdup (e_contact_field_name (E_CONTACT_FILE_AS));
 	} else if (g_str_equal (prop_name, BOOK_BACKEND_PROPERTY_SUPPORTED_FIELDS)) {
@@ -1249,9 +1176,6 @@ e_book_backend_kolab_class_init (EBookBackendKolabClass *klass)
 	sync_class->remove_sync = book_backend_kolab_remove;
 	sync_class->refresh_sync = book_backend_kolab_refresh;
 	sync_class->get_backend_property_sync = book_backend_kolab_get_backend_property;
-#if 0 /* probably not needed */
-	sync_class->set_backend_property_sync = book_backend_kolab_set_backend_property;
-#endif
 	sync_class->create_contacts_sync = book_backend_kolab_create_contacts;
 	sync_class->remove_contacts_sync = book_backend_kolab_remove_contacts;
 	sync_class->modify_contacts_sync = book_backend_kolab_modify_contacts;
