@@ -73,15 +73,6 @@ struct _EBookBackendKolabClass {
 GType
 e_book_backend_kolab_get_type (void) G_GNUC_CONST;
 
-#if 0
-EBookBackend*
-e_book_backend_kolab_new (void);
-
-void
-e_book_backend_kolab_set_koma_table (EBookBackendKolab *kolab,
-                                     GHashTable *koma_objects);
-#endif
-
 G_END_DECLS
 
 /*----------------------------------------------------------------------------*/
