@@ -35,8 +35,8 @@
 #include <gio/gio.h>
 
 #include <libekolab/kolab-mail-access.h>
-#include <libecal/e-cal.h>
-#include <libedata-cal/e-cal-backend-cache.h>
+#include <libecal/libecal.h>
+#include <libedata-cal/libedata-cal.h>
 
 /*----------------------------------------------------------------------------*/
 
@@ -84,9 +84,9 @@ kolab_util_calendar_cache_get_tz (ECalBackendCache *cache,
                                   ECalComponent *comp);
 
 ECalComponent*
-kolab_util_calendar_cache_get_object (ECalBackendCache *cal_cache,
+kolab_util_calendar_cache_get_object (ECalBackendSync *backend,
+                                      ECalBackendCache *cal_cache,
                                       KolabMailAccess *koma,
-                                      const gchar *uri,
                                       const gchar *uid,
                                       gboolean bulk,
                                       GCancellable *cancellable,
@@ -100,26 +100,26 @@ kolab_util_calendar_cache_remove_instance (ECalBackendCache *cal_cache,
                                            const gchar *rid);
 
 gboolean
-kolab_util_calendar_cache_assure_uid_on_ecalcomponent (ECalBackendCache *cache,
+kolab_util_calendar_cache_assure_uid_on_ecalcomponent (ECalBackendSync *backend,
+                                                       ECalBackendCache *cache,
                                                        KolabMailAccess *koma,
                                                        ECalComponent *ecalcomp,
-                                                       const gchar *uri,
                                                        gboolean bulk,
                                                        GCancellable *cancellable,
                                                        GError **error);
 
 gboolean
-kolab_util_calendar_cache_update_on_query (ECalBackendCache *cache,
+kolab_util_calendar_cache_update_on_query (ECalBackendSync *backend,
+                                           ECalBackendCache *cache,
                                            KolabMailAccess *koma,
                                            const gchar *query,
-                                           const gchar *uri,
                                            GCancellable *cancellable,
                                            GError **error);
 
 gboolean
-kolab_util_calendar_cache_update_object (ECalBackendCache *cache,
+kolab_util_calendar_cache_update_object (ECalBackendSync *backend,
+                                         ECalBackendCache *cache,
                                          KolabMailAccess *koma,
-                                         const gchar *uri,
                                          const gchar *uid,
                                          gboolean bulk,
                                          GCancellable *cancellable,
