@@ -75,6 +75,14 @@ e_kolab_folder_metadata_ui_new (void);
 void
 e_kolab_folder_metadata_ui_free (KolabFolderMetaUIData *uidata);
 
+void
+e_kolab_folder_metadata_ui_update_from_uidata (KolabFolderMetaUIData *uidata);
+
+gboolean
+e_kolab_folder_metadata_ui_query_metadata (KolabFolderMetaUIData *uidata,
+                                           GCancellable *cancellable,
+                                           GError **err);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _E_KOLAB_FOLDER_METADATA_H_ */
