@@ -96,6 +96,14 @@ e_kolab_folder_permissions_write_data_to_folder (const KolabDataImapAccount *acc
                                                  const KolabDataFolderPermissions *data,
                                                  GError **err);
 
+void
+e_kolab_folder_permissions_ui_update_from_uidata (KolabFolderPermUIData *uidata);
+
+gboolean
+e_kolab_folder_permissions_ui_query_acl (KolabFolderPermUIData *uidata,
+                                         GCancellable *cancellable,
+                                         GError **err);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _E_KOLAB_FOLDER_PERMISSIONS_H_ */
