@@ -114,29 +114,20 @@ struct _KolabFolderPropUIWidgets {
 
 typedef struct _KolabFolderPropUIData KolabFolderPropUIData;
 struct _KolabFolderPropUIData {
+	EShellView *shell_view;
 	KolabFolderPropUIWidgets *widgets;
 	KolabFolderMetaUIData *meta_ui_data;
 	KolabFolderPermUIData *perm_ui_data;
 	KolabDataImapAccount *account;
 };
 
-static void
-kolab_folder_prop_ui_widgets_enable (KolabFolderPropUIWidgets *widgets,
-                                     gboolean enabled)
-{
-	g_return_if_fail (widgets != NULL);
-	(void)enabled; /* FIXME */
-
-	/* FIXME implement me */
-	g_warning ("%s: FIXME implement me", __func__);
-}
-
 static KolabFolderPropUIData*
 kolab_folder_prop_ui_data_new ()
 {
 	KolabFolderPropUIData *uidata = NULL;
 
 	uidata = g_new0 (KolabFolderPropUIData, 1);
+	uidata->shell_view = NULL;
 	uidata->widgets = g_new0 (KolabFolderPropUIWidgets, 1);
 	uidata->meta_ui_data = NULL;
 	uidata->perm_ui_data = NULL;
@@ -151,6 +142,11 @@ kolab_folder_prop_ui_data_free (KolabFolderPropUIData *uidata)
 	if (uidata == NULL)
 		return;
 
+	/* FIXME do we need to ref/unref the shell view? */
+#if 0
+	g_object_unref (uidata->shell_view);
+#endif
+
 	/* the actual widgets will have been deleted already,
 	 * so just deleting the struct shell here
 	 */
@@ -182,6 +178,18 @@ kolab_folder_prop_ui_clear_all_entries (GObject *dialog)
 	g_warning ("%s: FIXME implement me", __func__);
 }
 
+static void
+kolab_folder_prop_ui_notebook_enable (KolabFolderPropUIData *uidata,
+                                      gboolean enable)
+{
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (GTK_IS_NOTEBOOK (uidata->widgets->notebook));
+
+	gtk_widget_set_sensitive (uidata->widgets->notebook,
+	                          enable);
+}
+
 static void
 kolab_folder_prop_ui_response_cb (GObject *dialog,
                                   gint response_id)
@@ -205,19 +213,14 @@ kolab_folder_prop_ui_response_cb (GObject *dialog,
 /*----------------------------------------------------------------------------*/
 /* internal statics (UI) */
 
-static void
-kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
-                                            EShellView *shell_view)
+static KolabFolderPropUIData*
+kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 {
 	KolabFolderPropUIData *uidata = NULL;
-	GObject *dialog = NULL;
-	GtkWidget *content = NULL;
-	GtkNotebook *notebook = NULL;
 	gchar *foldername = NULL;
 	gchar *sourcename = NULL;
 
-	g_return_if_fail (action != NULL);
-	g_return_if_fail (E_IS_SHELL_VIEW (shell_view));
+	g_return_val_if_fail (E_IS_SHELL_VIEW (shell_view), NULL);
 
 	foldername = e_kolab_plugin_util_ui_get_selected_foldername (shell_view);
 	if (foldername == NULL) {
@@ -230,14 +233,16 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 		 */
 		g_warning ("%s()[%u]: Selected folder is no Kolab folder node",
 		           __func__, __LINE__);
-		return;
+		return NULL;
 	}
 
 	/* sourcename may be NULL */
 	sourcename = e_kolab_plugin_util_ui_get_selected_sourcename (shell_view);
 
 	uidata = kolab_folder_prop_ui_data_new ();
+	uidata->shell_view = shell_view; /* FIXME ref the view? */
 	uidata->widgets->alert_bar = e_alert_bar_new ();
+	uidata->widgets->notebook = gtk_notebook_new ();
 
 	uidata->widgets->selected_folder =
 		e_kolab_plugin_util_ui_selected_folder_widget (foldername,
@@ -268,17 +273,25 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 	if (sourcename != NULL)
 		g_free (sourcename);
 
-	/* FIXME get account data here */
 	uidata->account = kolab_data_imap_account_new ();
 
-	dialog = G_OBJECT (uidata->widgets->dialog);
-	g_signal_connect (dialog, "response", G_CALLBACK (kolab_folder_prop_ui_response_cb), NULL);
-	g_object_set_data_full (dialog, E_KOLAB_PROP_DLG_UIDATA, uidata, kolab_folder_prop_ui_data_destroy);
+	return uidata;
+}
 
-	content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+static void
+kolab_folder_prop_ui_dialog_assemble (KolabFolderPropUIData *uidata)
+{
+	GtkWidget *content = NULL;
+	GtkNotebook *notebook = NULL;
+
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (GTK_IS_DIALOG (uidata->widgets->dialog));
+	g_return_if_fail (E_IS_ALERT_BAR (uidata->widgets->alert_bar));
+
+	content = gtk_dialog_get_content_area (GTK_DIALOG (uidata->widgets->dialog));
 	gtk_container_add (GTK_CONTAINER (content), uidata->widgets->alert_bar);
 	gtk_container_add (GTK_CONTAINER (content), uidata->widgets->selected_folder);
-	uidata->widgets->notebook = gtk_notebook_new ();
 	notebook = GTK_NOTEBOOK (uidata->widgets->notebook);
 	gtk_notebook_set_show_border (notebook, TRUE);
 	gtk_container_add (GTK_CONTAINER (content),
@@ -303,20 +316,167 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 	                                 uidata->perm_ui_data->widgets->container,
 	                                 C_("Kolab Folder Properties",
 	                                    "IMAP Access Control"));
+	gtk_widget_show_all (content);
+}
 
-	/* TODO connect signals */
+static void
+kolab_folder_prop_ui_dialog_visible (KolabFolderPropUIData *uidata,
+                                     gboolean visible)
+{
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (GTK_IS_DIALOG (uidata->widgets->dialog));
+
+	if (visible)
+		gtk_widget_show (uidata->widgets->dialog);
+	else
+		gtk_widget_hide (uidata->widgets->dialog);
+}
+
+static void
+kolab_folder_prop_ui_dialog_update_from_uidata (KolabFolderPropUIData *uidata)
+{
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (GTK_IS_DIALOG (uidata->widgets->dialog));
+
+	e_kolab_folder_metadata_ui_update_from_uidata (uidata->meta_ui_data);
+	e_kolab_folder_permissions_ui_update_from_uidata (uidata->perm_ui_data);
+}
+
+static void
+kolab_folder_prop_ui_alertbar_visible (KolabFolderPropUIData *uidata,
+                                       gboolean visible)
+{
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (E_IS_ALERT_BAR (uidata->widgets->alert_bar));
+
+	if (visible)
+		gtk_widget_show (uidata->widgets->alert_bar);
+	else
+		gtk_widget_hide (uidata->widgets->alert_bar);
+}
+
+static void
+kolab_folder_prop_ui_alertbar_show_error (KolabFolderPropUIData *uidata,
+                                          GError *err)
+{
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (E_IS_ALERT_BAR (uidata->widgets->alert_bar));
+
+	if (err == NULL)
+		return;
+
+	g_warning ("%s: FIXME implement me", __func__);
+}
+
+static gboolean
+kolab_folder_prop_ui_query_metadata (KolabFolderPropUIData *uidata,
+                                     GCancellable *cancellable,
+                                     GError **err)
+{
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
+	g_return_val_if_fail (uidata != NULL, FALSE);
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	ok = e_kolab_folder_metadata_ui_query_metadata (uidata->meta_ui_data,
+	                                                cancellable,
+	                                                &tmp_err);
+	if (tmp_err != NULL)
+		g_propagate_error (err, tmp_err);
+
+	return ok;
+}
+
+static gboolean
+kolab_folder_prop_ui_query_acl (KolabFolderPropUIData *uidata,
+                                GCancellable *cancellable,
+                                GError **err)
+{
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
+	g_return_val_if_fail (uidata != NULL, FALSE);
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	ok = e_kolab_folder_permissions_ui_query_acl (uidata->perm_ui_data,
+	                                              cancellable,
+	                                              &tmp_err);
+	if (tmp_err != NULL)
+		g_propagate_error (err, tmp_err);
+
+	return ok;
+}
+
+static void
+kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
+                                            EShellView *shell_view)
+{
+	KolabFolderPropUIData *uidata = NULL;
+	GObject *dialog = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = TRUE;
+
+	g_return_if_fail (action != NULL);
+	g_return_if_fail (E_IS_SHELL_VIEW (shell_view));
+
+	/* create widgets and payload data structures */
+	uidata = kolab_folder_prop_ui_dialog_data_new (shell_view);
+	g_return_if_fail (uidata != NULL);
+
+	/* assemble dialog */
+	kolab_folder_prop_ui_dialog_assemble (uidata);
+
+	/* connect response callback */
+	dialog = G_OBJECT (uidata->widgets->dialog);
+	g_signal_connect (dialog, "response", G_CALLBACK (kolab_folder_prop_ui_response_cb), NULL);
+	g_object_set_data_full (dialog, E_KOLAB_PROP_DLG_UIDATA, uidata, kolab_folder_prop_ui_data_destroy);
+
+	kolab_folder_prop_ui_notebook_enable (uidata, FALSE);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
-
-	kolab_folder_prop_ui_widgets_enable (uidata->widgets, FALSE);
-
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
 	                                   GTK_RESPONSE_OK,
 	                                   FALSE);
 
-	gtk_widget_show_all (content);
-	gtk_widget_hide (uidata->widgets->alert_bar);
-	gtk_widget_show (uidata->widgets->dialog);
+	kolab_folder_prop_ui_alertbar_visible (uidata, FALSE);
+	kolab_folder_prop_ui_dialog_visible (uidata, TRUE);
+
+	/* TODO
+	 *
+	 * - add an EActivity bar and a cancellation stack
+	 *   so we can cancel getting the info as well as
+	 *   cancel setting the new options later on
+	 *
+	 */
+
+	ok = kolab_folder_prop_ui_query_metadata (uidata,
+	                                          NULL, /* add cancellation stack here */
+	                                          &tmp_err);
+	if (! ok)
+		goto exit;
+
+	ok = kolab_folder_prop_ui_query_acl (uidata,
+	                                     NULL, /* add cancellation stack here */
+	                                     &tmp_err);
+	if (! ok)
+		goto exit;
+
+	kolab_folder_prop_ui_dialog_update_from_uidata (uidata);
+	kolab_folder_prop_ui_notebook_enable (uidata, TRUE);
+
+ exit:
+	if (tmp_err != NULL) {
+		kolab_folder_prop_ui_alertbar_show_error (uidata,
+		                                          tmp_err);
+		g_error_free (tmp_err);
+	}
 }
 
 static void
