@@ -32,6 +32,7 @@
 #include <glib/gi18n-lib.h>
 
 #include "camel-imapx-extd-store.h"
+#include "camel-imapx-extd-store-friend.h"
 
 /*----------------------------------------------------------------------------*/
 
@@ -45,6 +46,7 @@ static CamelStoreClass *parent_store_class = NULL;
 /*----------------------------------------------------------------------------*/
 
 /* forward declarations */
+static gboolean imapx_extd_store_register_capability_flags (CamelIMAPXExtdStore *self);
 static void imapx_extd_store_initable_init (GInitableIface *interface);
 static void imapx_extd_store_network_service_init (CamelNetworkServiceInterface *interface);
 static void imapx_extd_store_subscribable_init (CamelSubscribableInterface *interface);
@@ -55,6 +57,8 @@ extern CamelServiceAuthType camel_imapx_password_authtype;
 typedef struct _CamelIMAPXExtdStorePrivate CamelIMAPXExtdStorePrivate;
 struct _CamelIMAPXExtdStorePrivate {
 	CamelImapxMetadata *md; /* raw annotation data (different from CamelKolabImapxMetadata) */
+	CamelImapxAcl *acl; /* IMAP ACL data */
+	guint32 imapx_capa_flag_ids[CAMEL_IMAPX_EXTD_STORE_CAPA_LAST_FLAG];
 };
 
 #define CAMEL_IMAPX_EXTD_STORE_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CAMEL_TYPE_IMAPX_EXTD_STORE, CamelIMAPXExtdStorePrivate))
@@ -78,6 +82,7 @@ camel_imapx_extd_store_init (CamelIMAPXExtdStore *self)
 	CamelIMAPXExtdStorePrivate *priv = NULL;
 	CamelIMAPXStore *istore = NULL;
 	CamelIMAPXConnManager *cm = NULL;
+	gint ii = 0;
 
 	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
 
@@ -86,6 +91,9 @@ camel_imapx_extd_store_init (CamelIMAPXExtdStore *self)
 
 	priv->md = camel_imapx_metadata_new (CAMEL_IMAPX_METADATA_PROTO_INVAL,
 	                                     FALSE);
+	for (ii = 0; ii < CAMEL_IMAPX_EXTD_STORE_CAPA_LAST_FLAG; ii++)
+		priv->imapx_capa_flag_ids[ii] = 0;
+	priv->acl = camel_imapx_acl_new (FALSE);
 
 	/* remove existing conn manager.
 	 * should not normally be necessary
@@ -165,6 +173,8 @@ camel_imapx_extd_store_finalize (GObject *object)
 
 	if (priv->md != NULL)
 		camel_imapx_metadata_free (priv->md);
+	if (priv->acl != NULL)
+		camel_imapx_acl_free (priv->acl);
 
 	G_OBJECT_CLASS (camel_imapx_extd_store_parent_class)->finalize (object);
 }
@@ -172,6 +182,60 @@ camel_imapx_extd_store_finalize (GObject *object)
 /*----------------------------------------------------------------------------*/
 /* internal statics */
 
+static void
+imapx_extd_store_set_capa_flag_id (CamelIMAPXExtdStore *self,
+                                   camel_imapx_extd_store_capa_flag_t flag,
+                                   guint32 id)
+{
+	CamelIMAPXExtdStorePrivate *priv = NULL;
+
+	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
+	g_assert (flag < CAMEL_IMAPX_EXTD_STORE_CAPA_LAST_FLAG);
+
+	priv = CAMEL_IMAPX_EXTD_STORE_PRIVATE (self);
+
+	priv->imapx_capa_flag_ids[flag] = id;
+}
+
+static gboolean
+imapx_extd_store_register_capability_flags (CamelIMAPXExtdStore *self)
+{
+	guint32 capa_flag_id = 0;
+
+	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
+
+	/* Registering the capability flags must be done
+	 * before CamelIMAPXServer init. The ConnManager
+	 * hands us out an inited and already connected
+	 * CamelIMAPXServer instance, which will already
+	 * have seen the server capabilities (and it will
+	 * have ignored the extended ones it did not know
+	 * about then). Hence, we need to make known to the
+	 * IMAPX utils the new flags before creating the
+	 * first CamelIMAPXServer instance. The registration
+	 * is not per CamelIMAPXServer, but global.
+	 * It is safe to call imapx_register_capability()
+	 * multiple times (if a capa is already registered, its
+	 * id is returned immediately).
+	 */
+
+	/* ANNOTATEMORE server capability flag */
+	capa_flag_id = imapx_register_capability (IMAPX_IMAP_TOKEN_ANNOTATEMORE);
+	g_return_val_if_fail (capa_flag_id > 0, FALSE);
+	imapx_extd_store_set_capa_flag_id (self,
+	                                   CAMEL_IMAPX_EXTD_STORE_CAPA_FLAG_ANNOTATEMORE,
+	                                   capa_flag_id);
+
+	/* (register METADATA server capability flag here) */
+
+	/* ACL server capability flag */
+	capa_flag_id = imapx_register_capability (IMAPX_IMAP_TOKEN_ACL);
+	g_return_val_if_fail (capa_flag_id > 0, FALSE);
+	imapx_extd_store_set_capa_flag_id (self,
+	                                   CAMEL_IMAPX_EXTD_STORE_CAPA_FLAG_ACL,
+	                                   capa_flag_id);
+	return TRUE;
+}
 
 /*----------------------------------------------------------------------------*/
 /* class functions */
@@ -283,6 +347,7 @@ imapx_extd_store_get_server (CamelIMAPXStore *self,
 {
 	CamelIMAPXServer *server = NULL;
 	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
 
 	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
 	/* foldername may be NULL */
@@ -299,7 +364,20 @@ imapx_extd_store_get_server (CamelIMAPXStore *self,
 		return NULL;
 	}
 
-	g_assert (CAMEL_IS_IMAPX_SERVER (server));
+	g_return_val_if_fail (CAMEL_IS_IMAPX_SERVER (server), NULL);
+
+	/* this can be called multiple times,
+	 * which is okay (init() just returns
+	 * TRUE if already inited)
+	 */
+	ok = camel_imapx_extd_server_init (server,
+	                                   cancellable,
+	                                   &tmp_err);
+	if (! ok) {
+		g_propagate_error (err, tmp_err);
+		g_object_unref (server);
+		return NULL;
+	}
 
 	return server;
 }
@@ -327,6 +405,34 @@ imapx_extd_store_metadata_get_proto (CamelIMAPXExtdStore *self)
 
 	proto = camel_imapx_metadata_get_proto (priv->md);
 
+	if (proto != CAMEL_IMAPX_METADATA_PROTO_INVAL)
+		return proto;
+
+	/* Set the protocol type according to the
+	 * announced server capability, if we have
+	 * one advertised by the server (we assume
+	 * that the server advertises either one
+	 * or none, but not both)
+	 */
+
+	/* ANNOTATEMORE */
+	if (priv->imapx_capa_flag_ids[CAMEL_IMAPX_EXTD_STORE_CAPA_FLAG_ANNOTATEMORE]) {
+		proto = CAMEL_IMAPX_METADATA_PROTO_ANNOTATEMORE;
+		goto skip;
+	}
+
+	/* METADATA */
+	if (priv->imapx_capa_flag_ids[CAMEL_IMAPX_EXTD_STORE_CAPA_FLAG_METADATA]) {
+		proto = CAMEL_IMAPX_METADATA_PROTO_METADATA;
+		goto skip;
+	}
+
+ skip:
+	if (proto != CAMEL_IMAPX_METADATA_PROTO_INVAL) {
+		if (! camel_imapx_metadata_set_proto (priv->md, proto))
+			proto = CAMEL_IMAPX_METADATA_PROTO_INVAL;
+	}
+
 	return proto;
 }
 
@@ -382,7 +488,7 @@ imapx_extd_store_get_metadata (CamelIMAPXExtdStore *self,
 	 * the result inside this object for later resection
 	 */
 	if (do_resect)
-		md = camel_imapx_metadata_resect (&(priv->md));
+		md = camel_imapx_metadata_resect (priv->md);
 
 	return md;
 }
@@ -446,12 +552,27 @@ imapx_extd_store_initable_initialize (GInitable *initable,
                                       GCancellable *cancellable,
                                       GError **err)
 {
+	CamelIMAPXExtdStore *self = NULL;
 	gboolean ok = FALSE;
 
 	g_assert (G_IS_INITABLE (initable));
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	self = CAMEL_IMAPX_EXTD_STORE (initable);
+
+	/* register IMAPX capability flags (to be done before
+	 * instantiating the first CamelIMAPXServer)
+	 */
+	ok = imapx_extd_store_register_capability_flags (self);
+	if (! ok) {
+		g_set_error (err,
+		             CAMEL_IMAPX_ERROR,
+		             1, /* FIXME define and add a sensible code here */
+		             _("Cannot register extended IMAP capability flags"));
+		return FALSE;
+	}
+
 	/* chain up to parent interface's init() method. */
 	ok = parent_initable_iface->init (initable,
 	                                  cancellable,
@@ -674,7 +795,6 @@ camel_imapx_extd_store_set_metadata (CamelIMAPXExtdStore *self,
 
 /*----------------------------------------------------------------------------*/
 /* "friend" API */
-#include "camel-imapx-extd-store-friend.h"
 
 CamelImapxMetadata*
 camel_imapx_extd_store_get_md_table (CamelIMAPXExtdStore *self)
@@ -687,8 +807,35 @@ camel_imapx_extd_store_get_md_table (CamelIMAPXExtdStore *self)
 
 	/* TODO does this need to be thread-safe? */
 
-	g_object_ref (priv->md);
 	return priv->md;
 }
 
+CamelImapxAcl*
+camel_imapx_extd_store_get_acl_table (CamelIMAPXExtdStore *self)
+{
+	CamelIMAPXExtdStorePrivate *priv = NULL;
+
+	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
+
+	priv = CAMEL_IMAPX_EXTD_STORE_PRIVATE (self);
+
+	/* TODO does this need to be thread-safe? */
+
+	return priv->acl;
+}
+
+guint32
+camel_imapx_extd_store_get_capa_flag_id (CamelIMAPXExtdStore *self,
+                                         camel_imapx_extd_store_capa_flag_t flag)
+{
+	CamelIMAPXExtdStorePrivate *priv = NULL;
+
+	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
+	g_assert (flag < CAMEL_IMAPX_EXTD_STORE_CAPA_LAST_FLAG);
+
+	priv = CAMEL_IMAPX_EXTD_STORE_PRIVATE (self);
+
+	return priv->imapx_capa_flag_ids[flag];
+}
+
 /*----------------------------------------------------------------------------*/
