@@ -270,7 +270,7 @@ imapx_store_get_foldertype (CamelKolabIMAPXStore *self,
 		 * means we cannot return a folder type
 		 * other than UNKNOWN
 		 */
-		g_debug ("%s: must be online to complete this operation",
+		g_debug ("%s: You must be online to complete this operation",
 		         __func__);
 		return KOLAB_FOLDER_TYPE_UNKNOWN;
 	}
@@ -530,6 +530,7 @@ imapx_store_get_folder_info_sync (CamelKolabIMAPXStore *self,
                                   const gchar *top,
                                   CamelStoreGetFolderInfoFlags flags,
                                   gboolean do_updatedb,
+                                  gboolean get_all,
                                   GCancellable *cancellable,
                                   GError **err)
 {
@@ -556,12 +557,16 @@ imapx_store_get_folder_info_sync (CamelKolabIMAPXStore *self,
 		goto exit;
 
 	if (fi != NULL) {
-		k_fi = imapx_store_folder_info_build_restricted (self,
-		                                                 fi,
-		                                                 do_updatedb,
-		                                                 cancellable,
-		                                                 &tmp_err);
-		camel_store_free_folder_info (CAMEL_STORE (self), fi);
+		if (get_all) {
+			k_fi = fi;
+		} else {
+			k_fi = imapx_store_folder_info_build_restricted (self,
+			                                                 fi,
+			                                                 do_updatedb,
+			                                                 cancellable,
+			                                                 &tmp_err);
+			camel_store_free_folder_info (CAMEL_STORE (self), fi);
+		}
 
 		if (tmp_err != NULL)
 			goto exit;
@@ -610,12 +615,14 @@ kolab_imapx_store_get_name (CamelService *service,
 
 	g_assert (CAMEL_IS_KOLAB_IMAPX_STORE (service));
 
-	settings = camel_service_get_settings (service);
+	settings = camel_service_ref_settings (service);
 
 	network_settings = CAMEL_NETWORK_SETTINGS (settings);
 	host = camel_network_settings_dup_host (network_settings);
 	user = camel_network_settings_dup_user (network_settings);
 
+	g_object_unref (settings);
+
 	if (brief)
 		name = g_strdup_printf (_("Kolab server %s"), host);
 	else
@@ -669,7 +676,8 @@ kolab_imapx_store_get_folder_info_sync (CamelStore *self,
 	k_fi = imapx_store_get_folder_info_sync (myself,
 	                                         top,
 	                                         flags,
-	                                         TRUE, /* update SQLite DBs */
+	                                         TRUE,  /* update SQLite DBs */
+	                                         FALSE, /* get folders matching context only */
 	                                         cancellable,
 	                                         err);
 
@@ -694,6 +702,7 @@ kolab_imapx_store_get_folder_info_online (CamelKolabIMAPXStore *self,
 	                                         top,
 	                                         flags,
 	                                         FALSE, /* do not update DBs */
+	                                         TRUE,  /* get info for all folders, disregard context */
 	                                         cancellable,
 	                                         err);
 
