@@ -27,7 +27,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libecal/e-cal-util.h>
+#include <libecal/libecal.h>
 #include "kolab-conv.h"
 #include "evolution/evolution.h"
 #include "kolab/kolab.h"
