@@ -118,4 +118,26 @@ kolab_util_camel_imapx_folder_get_uidvalidity (CamelIMAPXFolder *folder)
 	return uidvalidity;
 }
 
+GList*
+kolab_util_camel_folderlist_from_folderinfo (CamelFolderInfo *fi)
+{
+	GList *folders_self = NULL;
+	GList *folders_chld = NULL;
+	GList *folders_next = NULL;
+	
+	if (fi == NULL)
+		return NULL;
+
+	folders_chld = kolab_util_camel_folderlist_from_folderinfo (fi->child);
+	folders_next = kolab_util_camel_folderlist_from_folderinfo (fi->next);
+
+	folders_self = g_list_append (folders_self, g_strdup (fi->full_name));
+	if (folders_chld != NULL)
+		folders_self = g_list_concat (folders_self, folders_chld);
+	if (folders_next != NULL)
+		folders_self = g_list_concat (folders_self, folders_next);
+
+	return folders_self;
+}
+
 /*----------------------------------------------------------------------------*/
