@@ -74,6 +74,9 @@ kolab_util_camel_get_storage_path (CamelService *service,
 guint64
 kolab_util_camel_imapx_folder_get_uidvalidity (CamelIMAPXFolder *folder);
 
+GList*
+kolab_util_camel_folderlist_from_folderinfo (CamelFolderInfo *fi);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _KOLAB_UTIL_CAMEL_H_ */
