@@ -61,7 +61,7 @@ static gboolean kolab_util_folder_is_initialized = FALSE;
 /*----------------------------------------------------------------------------*/
 
 static void
-kolab_util_folder_type_map_init (void)
+util_folder_type_map_init (void)
 {
 	gint ii = 0;
 	kolab_folder_type_map = g_hash_table_new (g_str_hash, g_str_equal);
@@ -74,7 +74,7 @@ kolab_util_folder_type_map_init (void)
 }
 
 static void
-kolab_util_folder_type_map_uninit (void)
+util_folder_type_map_uninit (void)
 {
 	g_hash_table_destroy (kolab_folder_type_map);
 	kolab_folder_type_map = NULL;
@@ -88,7 +88,7 @@ kolab_util_folder_init (void)
 	if (kolab_util_folder_is_initialized)
 		return;
 
-	kolab_util_folder_type_map_init ();
+	util_folder_type_map_init ();
 
 	kolab_util_folder_is_initialized = TRUE;
 }
@@ -99,7 +99,7 @@ kolab_util_folder_shutdown (void)
 	if (! kolab_util_folder_is_initialized)
 		return;
 
-	kolab_util_folder_type_map_uninit ();
+	util_folder_type_map_uninit ();
 
 	kolab_util_folder_is_initialized = FALSE;
 }
@@ -190,4 +190,46 @@ kolab_util_folder_type_match_with_context_id (KolabFolderTypeID type_id,
 	return TRUE;
 }
 
+KolabFolderDescriptor*
+kolab_util_folder_descriptor_new (const gchar *foldername,
+                                  KolabFolderTypeID type_id)
+{
+	KolabFolderDescriptor *desc = NULL;
+
+	g_assert (foldername != NULL);
+	g_assert ((type_id > KOLAB_FOLDER_TYPE_INVAL) &&
+	          (type_id < KOLAB_FOLDER_LAST_TYPE));
+
+	desc = g_new0 (KolabFolderDescriptor, 1);
+	desc->name = g_strdup (foldername);
+	desc->type_id = type_id;
+
+	return desc;
+}
+
+void
+kolab_util_folder_descriptor_free (KolabFolderDescriptor *desc)
+{
+	if (desc == NULL)
+		return;
+
+	if (desc->name != NULL)
+		g_free (desc->name);
+
+	g_free (desc);
+}
+
+void
+kolab_util_folder_descriptor_glist_free (GList *list)
+{
+	GList *list_ptr = list;
+
+	while (list_ptr != NULL) {
+		kolab_util_folder_descriptor_free (list_ptr->data);
+		list_ptr = g_list_next (list_ptr);
+	}
+	if (list != NULL)
+		g_list_free (list);
+}
+
 /*----------------------------------------------------------------------------*/
